@@ -9,7 +9,7 @@ ksboot  <- function(x, y, nboots=1000, alternative=c("two.sided", "less", "great
   x.s  <- sample(1:obs, obs, replace=TRUE)
   xtmp <- w[x.s[1:nx]]
   ytmp <- w[x.s[(nx + 1):obs]]
-  ks.s <- ks.test(xtmp, ytmp, alternative=alternative)$statistic
+  ks.s <- suppressWarnings(ks.test(xtmp, ytmp, alternative=alternative)$statistic)
   if (ks.s >= (ks.f$statistic - tol)) bbcount <- bbcount + 1
  }
  ksboot.pval  <- bbcount/nboots
